==> nextcloud-29.0.5.tgz: nextcloud/apps/viewer/l10n/is.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Skoðari",
    "Simple file viewer with slideshow for media" : "Einfaldur skráalesari með skyggnusýningu fyrir margmiðlunargögn",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Sýndu nýjustu myndirnar og myndskeiðin úr fríinu þínu, birtu kafla úr skúffuskáldskapnum þínum beint á Nextcloud, veldu skemmtilegustu GIF-myndirnar úr safninu þínu með forskoðun á eftirlætisskránum þínum, og margt fleira!",
    "Your browser does not support audio." : "Vafrinn þinn styður ekki hljóð.",
    "Error loading {name}" : "Villa við að hlaða inn {name}",
    "Image saved" : "Mynd vistuð",
    "Error saving image" : "Villa við að vista mynd",
    "Unsaved changes" : "Óvistaðar breytingar",
    "Drop changes" : "Henda breytingum",
    "LIVE" : "BEINT",
    "Your browser does not support videos." : "Vafrinn þinn styður ekki myndskeið.",
    "Edit" : "Breyta",
    "Exit full screen" : "Fara úr skjáfylliham",
    "Full screen" : "Skjáfylli",
    "Open sidebar" : "Opna hliðarspjald",
    "Download" : "Sækja",
    "Delete" : "Eyða",
    "This file no longer exists" : "Þessi skrá er ekki lengur til",
    "There is no plugin available to display this file type" : "Ekki er til nein viðbót til að birta þessa tegund af skrám",
    "View" : "Skoða",
    "Name" : "Heiti",
    "Save" : "Vista",
    "Save as" : "Vista sem",
    "Back" : "Til baka",
    "Loading …" : "Hleð inn …",
    "Reset" : "Endurstilla",
    "All changes will be lost." : "Allar breytingar munu tapast.",
    "Are you sure you want to continue?" : "Ertu viss um að þú viljir halda áfram?",
    "Cancel" : "Hætta við",
    "Continue" : "Halda áfram",
    "Undo" : "Undo",
    "Redo" : "Redo",
    "Show original image" : "Birta upprunalega mynd",
    "Zoom in" : "Renna að",
    "Zoom out" : "Renna frá",
    "Toggle zoom menu" : "Víxla aðdráttarvalmynd af/á",
    "Adjust" : "Aðlaga",
    "Fine-tune" : "Fínstilla",
    "Filters" : "Síur",
    "Watermark" : "Vatnsmerki",
    "Draw" : "Teikna",
    "Resize" : "Breyta stærð",
    "Invalid image." : "Ógild mynd.",
    "Error while uploading the image." : "Villa við að senda inn myndina.",
    "are not images" : "eru ekki myndir",
    "is not an image" : "er ekki mynd",
    "to be uploaded" : "á að senda inn",
    "Crop" : "Utansníða",
    "Original" : "Upprunalegt",
    "Custom" : "Sérsniðið",
    "Square" : "Ferningur",
    "Landscape" : "Lárétt",
    "Portrait" : "Lóðrétt",
    "Ellipse" : "Sporbaugur",
    "Classic TV" : "Hefðbundið sjónvarp",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Ör",
    "Blur" : "Móða",
    "Brightness" : "Birtustig",
    "Contrast" : "Birtuskil",
    "Un-flip X" : "Taka til baka flettingu X",
    "Flip X" : "Fletta X",
    "Un-flip Y" : "Taka til baka flettingu Y",
    "Flip Y" : "Fletta Y",
    "HSV" : "HSV",
    "Hue" : "Litblær",
    "Saturation" : "Litmettun",
    "Value" : "Gildi",
    "Image" : "Mynd",
    "Importing …" : "Innflutningur í gangi …",
    "+ Add image" : "+ Bæta við mynd",
    "Line" : "Lína",
    "Pen" : "Penni",
    "Polygon" : "Marghyrningur",
    "Sides" : "Hliðar",
    "Rectangle" : "Rétthyrningur",
    "Corner Radius" : "Radíus horns",
    "Width in pixels" : "Breidd í mynddílum",
    "Height in pixels" : "Hæð í mynddílum",
    "Toggle ratio lock" : "Víxla læsingu hlutfalla af/á",
    "Reset to original image size" : "Endurstilla í upprunalega myndstærð",
    "Rotate" : "Snúa",
    "Text" : "Texti",
    "Text spacing" : "Millibil texta",
    "Text alignment" : "Jöfnun texta",
    "Font family" : "Leturgerð",
    "Size" : "Stærð",
    "Letter spacing" : "Stafabil",
    "Line height" : "Línuhæð",
    "Warmth" : "Hlýleiki",
    "+ Add watermark" : "+ Bæta við vatnsmerki",
    "Choose watermark type" : "Veldu tegund vatnsmerkis",
    "Upload watermark" : "Senda inn vatnsmerki",
    "Add as text" : "Bæta við sem texta",
    "Padding" : "Fylling",
    "Shadow" : "Skuggi",
    "Horizontal" : "Lárétt",
    "Vertical" : "Lóðrétt",
    "Opacity" : "Ógegnsæi",
    "Position" : "Staða",
    "Stroke" : "Stroka",
    "Save image as" : "Vista mynd sem",
    "Extension" : "Skráarending",
    "Name is required." : "Nafn er nauðsynlegt.",
    "Quality" : "Gæði",
    "Saved image size (width x height)" : "Stærð vistaðrar myndar (breidd x hæð)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Athugaðu að valið afskurðarsvæði er minna en virkjuð stærðarbreyting gefur, sem gæti komið niður á gæðum",
    "Actual size (100%)" : "Raunstærð (100%)",
    "Fit size" : "Aðlaga stærð"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-30.0.16.tgz: nextcloud/apps/viewer/l10n/is.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Skoðari",
    "Simple file viewer with slideshow for media" : "Einfaldur skráalesari með skyggnusýningu fyrir margmiðlunargögn",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Sýndu nýjustu myndirnar og myndskeiðin úr fríinu þínu, birtu kafla úr skúffuskáldskapnum þínum beint á Nextcloud, veldu skemmtilegustu GIF-myndirnar úr safninu þínu með forskoðun á eftirlætisskránum þínum, og margt fleira!",
    "Your browser does not support audio." : "Vafrinn þinn styður ekki hljóð.",
    "Error loading {name}" : "Villa við að hlaða inn {name}",
    "Cancel" : "Hætta við",
    "Image saved" : "Mynd vistuð",
    "Error saving image" : "Villa við að vista mynd",
    "Play the live photo" : "Spila lifandi mynd",
    "LIVE" : "BEINT",
    "Your browser does not support videos." : "Vafrinn þinn styður ekki myndskeið.",
    "This file no longer exists" : "Þessi skrá er ekki lengur til",
    "There is no plugin available to display this file type" : "Ekki er til nein viðbót til að birta þessa tegund af skrám",
    "Edit" : "Breyta",
    "Exit full screen" : "Fara úr skjáfylliham",
    "Full screen" : "Skjáfylli",
    "Open sidebar" : "Opna hliðarspjald",
    "Download" : "Sækja",
    "Delete" : "Eyða",
    "View" : "Skoða",
    "Name" : "Heiti",
    "Save" : "Vista",
    "Save as" : "Vista sem",
    "Back" : "Til baka",
    "Loading …" : "Hleð inn …",
    "Reset" : "Endurstilla",
    "All changes will be lost." : "Allar breytingar munu tapast.",
    "Are you sure you want to continue?" : "Ertu viss um að þú viljir halda áfram?",
    "Apply" : "Virkja",
    "Warning" : "Aðvörun",
    "Confirm" : "Staðfesta",
    "Discard changes" : "Henda breytingum",
    "Undo" : "Undo",
    "Redo" : "Redo",
    "Show original image" : "Birta upprunalega mynd",
    "Zoom in" : "Renna að",
    "Zoom out" : "Renna frá",
    "Toggle zoom menu" : "Víxla aðdráttarvalmynd af/á",
    "Adjust" : "Aðlaga",
    "Fine-tune" : "Fínstilla",
    "Filters" : "Síur",
    "Watermark" : "Vatnsmerki",
    "Draw" : "Teikna",
    "Resize" : "Breyta stærð",
    "Image name" : "Heiti myndar",
    "Invalid image." : "Ógild mynd.",
    "Error while uploading the image." : "Villa við að senda inn myndina.",
    "are not images" : "eru ekki myndir",
    "is not an image" : "er ekki mynd",
    "to be uploaded" : "á að senda inn",
    "Crop" : "Utansníða",
    "Original" : "Upprunalegt",
    "Custom" : "Sérsniðið",
    "Square" : "Ferningur",
    "Landscape" : "Lárétt",
    "Portrait" : "Lóðrétt",
    "Ellipse" : "Sporbaugur",
    "Classic TV" : "Hefðbundið sjónvarp",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Ör",
    "Blur" : "Móða",
    "Brightness" : "Birtustig",
    "Contrast" : "Birtuskil",
    "Un-flip X" : "Taka til baka flettingu X",
    "Flip X" : "Fletta X",
    "Un-flip Y" : "Taka til baka flettingu Y",
    "Flip Y" : "Fletta Y",
    "HSV" : "HSV",
    "Hue" : "Litblær",
    "Saturation" : "Litmettun",
    "Value" : "Gildi",
    "Image" : "Mynd",
    "Importing …" : "Innflutningur í gangi …",
    "+ Add image" : "+ Bæta við mynd",
    "Upload image" : "Senda inn mynd",
    "From gallery" : "Úr myndasafni",
    "Line" : "Lína",
    "Pen" : "Penni",
    "Polygon" : "Marghyrningur",
    "Sides" : "Hliðar",
    "Rectangle" : "Rétthyrningur",
    "Corner Radius" : "Radíus horns",
    "Width in pixels" : "Breidd í mynddílum",
    "Height in pixels" : "Hæð í mynddílum",
    "Toggle ratio lock" : "Víxla læsingu hlutfalla af/á",
    "Reset to original image size" : "Endurstilla í upprunalega myndstærð",
    "Rotate" : "Snúa",
    "Text" : "Texti",
    "Text spacing" : "Millibil texta",
    "Text alignment" : "Jöfnun texta",
    "Font family" : "Leturgerð",
    "Size" : "Stærð",
    "Letter spacing" : "Stafabil",
    "Line height" : "Línuhæð",
    "Warmth" : "Hlýleiki",
    "+ Add watermark" : "+ Bæta við vatnsmerki",
    "+ Add text watermark" : "+ Bæta við textavatnsmerki",
    "Choose watermark type" : "Veldu tegund vatnsmerkis",
    "Upload watermark" : "Senda inn vatnsmerki",
    "Add as text" : "Bæta við sem texta",
    "Padding" : "Fylling",
    "Paddings" : "Fóðrun",
    "Shadow" : "Skuggi",
    "Horizontal" : "Lárétt",
    "Vertical" : "Lóðrétt",
    "Opacity" : "Ógegnsæi",
    "Transparency" : "Gegnsæi",
    "Position" : "Staða",
    "Stroke" : "Stroka",
    "Save image as" : "Vista mynd sem",
    "Extension" : "Skráarending",
    "Format" : "Snið",
    "Name is required." : "Nafn er nauðsynlegt.",
    "Quality" : "Gæði",
    "Saved image size (width x height)" : "Stærð vistaðrar myndar (breidd x hæð)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Athugaðu að valið afskurðarsvæði er minna en virkjuð stærðarbreyting gefur, sem gæti komið niður á gæðum",
    "Actual size (100%)" : "Raunstærð (100%)",
    "Fit size" : "Aðlaga stærð",
    "Select image to add …" : "Veldu mynd til bæta við …",
    "Failed to load image." : "Mistókst að opna myndina.",
    "Menu" : "Valmynd",
    "Width" : "Breidd",
    "Height" : "Hæð",
    "No preview available for this crop item" : "Engin forskoðun til fyrir þetta afskurðaratriði"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
